"""
W&B callback for CatBoost
"""

from .catboost import WandbCallback, log_summary

__all__ = ["log_summary", "WandbCallback"]
